/*
 *	%W%	(TriChlor) %G% %U%
 */
#ifndef _CHARSETV_H_
#define _CHARSETV_H_

/* Vietnamese 8-bit character set --- Viet_Std */

#define C_A_breve_hook_above	C_STX	/* ASCII  2 -- CTRL-B */
#define C_A_breve_tilde		C_ENQ	/* ASCII  5 -- CTRL-E */
#define C_A_circumflex_tilde	C_ACK	/* ASCII  6 -- CTRL-F */
#define C_Y_hook_above		C_DC4	/* ASCII 20 -- CTRL-T */
#define C_Y_tilde		C_EM	/* ASCII 25 -- CTRL-Y */
#define C_Y_dot_below		C_IS2	/* ASCII 30 -- CTRL-_ */

#define C_A_dot_below                  128
#define C_A_breve_acute                129
#define C_A_breve_grave                130
#define C_A_breve_dot_below            131
#define C_A_circumflex_acute           132
#define C_A_circumflex_grave           133
#define C_A_circumflex_hook_above      134
#define C_A_circumflex_dot_below       135
#define C_E_tilde                      136
#define C_E_dot_below                  137
#define C_E_circumflex_acute           138
#define C_E_circumflex_grave           139
#define C_E_circumflex_hook_above      140
#define C_E_circumflex_tilde           141
#define C_E_circumflex_dot_below       142
#define C_O_circumflex_acute           143
#define C_O_circumflex_grave           144
#define C_O_circumflex_hook_above      145
#define C_O_circumflex_tilde           146
#define C_O_circumflex_dot_below       147
#define C_O_horn_dot_below             148
#define C_O_horn_acute                 149
#define C_O_horn_grave                 150
#define C_O_horn_hook_above            151
#define C_I_dot_below                  152
#define C_O_hook_above                 153
#define C_O_dot_below                  154
#define C_I_hook_above                 155
#define C_U_hook_above                 156
#define C_U_tilde                      157
#define C_U_dot_below                  158
#define C_Y_grave                      159
#define C_O_tilde                      160
#define C_a_breve_acute                161
#define C_a_breve_grave                162
#define C_a_breve_dot_below            163
#define C_a_circumflex_acute           164
#define C_a_circumflex_grave           165
#define C_a_circumflex_hook_above      166
#define C_a_circumflex_dot_below       167
#define C_e_tilde                      168
#define C_e_dot_below                  169
#define C_e_circumflex_acute           170
#define C_e_circumflex_grave           171
#define C_e_circumflex_hook_above      172
#define C_e_circumflex_tilde           173
#define C_e_circumflex_dot_below       174
#define C_o_circumflex_acute           175
#define C_o_circumflex_grave           176
#define C_o_circumflex_hook_above      177
#define C_o_circumflex_tilde           178
#define C_O_horn_tilde                 179
#define C_O_horn                       180
#define C_o_circumflex_dot_below       181
#define C_o_horn_grave                 182
#define C_o_horn_hook_above            183
#define C_i_dot_below                  184
#define C_U_horn_dot_below             185
#define C_U_horn_acute                 186
#define C_U_horn_grave                 187
#define C_U_horn_hook_above            188
#define C_o_horn                       189
#define C_o_horn_acute                 190
#define C_U_horn                       191
#define C_A_grave                      192
#define C_A_acute                      193
#define C_A_circumflex                 194
#define C_A_tilde                      195
#define C_A_hook_above                 196
#define C_A_breve                      197
#define C_a_breve_hook_above           198
#define C_a_breve_tilde                199
#define C_E_grave                      200
#define C_E_acute                      201
#define C_E_circumflex                 202
#define C_E_hook_above                 203
#define C_I_grave                      204
#define C_I_acute                      205
#define C_I_tilde                      206
#define C_y_grave                      207
#define C_D_bar                        208
#define C_u_horn_acute                 209
#define C_O_grave                      210
#define C_O_acute                      211
#define C_O_circumflex                 212
#define C_a_dot_below                  213
#define C_y_hook_above                 214
#define C_u_horn_grave                 215
#define C_u_horn_hook_above            216
#define C_U_grave                      217
#define C_U_acute                      218
#define C_y_tilde                      219
#define C_y_dot_below                  220
#define C_Y_acute                      221
#define C_o_horn_tilde                 222
#define C_u_horn                       223
#define C_a_grave                      224
#define C_a_acute                      225
#define C_a_circumflex                 226
#define C_a_tilde                      227
#define C_a_hook_above                 228
#define C_a_breve                      229
#define C_u_horn_tilde                 230
#define C_a_circumflex_tilde           231
#define C_e_grave                      232
#define C_e_acute                      233
#define C_e_circumflex                 234
#define C_e_hook_above                 235
#define C_i_grave                      236
#define C_i_acute                      237
#define C_i_tilde                      238
#define C_i_hook_above                 239
#define C_d_bar                        240
#define C_u_horn_dot_below             241
#define C_o_grave                      242
#define C_o_acute                      243
#define C_o_circumflex                 244
#define C_o_tilde                      245
#define C_o_hook_above                 246
#define C_o_dot_below                  247
#define C_u_dot_below                  248
#define C_u_grave                      249
#define C_u_acute                      250
#define C_u_tilde                      251
#define C_u_hook_above                 252
#define C_y_acute                      253
#define C_o_horn_dot_below             254
#define C_U_horn_tilde                 255
                                
#endif /* _CHARSETV_H_ */
