/*
 *      %W%       TriChlor: %G% %U%
 */

#ifndef _PORTABLE_H_
#define _PORTABLE_H_

/* uncomment this for compilation on MS-Windows
#define _WINDOWS        1
*/

#if _WINDOWS
#define lint            /* so we won't get the SCCS strings */
#else /* not _WINDOWS */
#define FAR
#define PASCAL
#endif

/* for u_char, u_int */
#if _WINDOWS | _MSDOS
typedef unsigned char u_char;
typedef unsigned int u_int;
#else
#include <sys/types.h>
#endif

#endif /* _PORTABLE_H_ */
