/*
 *	@(#)charset.h	2.1       TriChlor: 3/16/92 07:43:17
 */

#ifndef _CHARSET_H_
#define _CHARSET_H_

#include "charseta.h"	/* ASCII set */
#include "charsetv.h"	/* Vietnamese set */

/* Renamed (*not* replaced) US-ASCII characters */
#define	C_acute		C_apostrophe
#define	C_grave		C_backquote
#define	C_hook_above	C_question_mark
#define	C_dot_below	C_period
#define	C_circumflex	C_caret
#define	C_breve		C_left_parenthesis
#define	C_horn		C_plus_sign

#endif /* _CHARSET_H_ */
