/*
 *	@(#)charseta.h	2.1	(TriChlor) 3/16/92 07:42:30
 */

#ifndef _CHARSETASCII_H_
#define _CHARSETASCII_H_

#define	C_NUL                       0
#define	C_SOH                       1
#define	C_STX                       2
#define	C_ETX                       3
#define	C_EOT                       4
#define	C_ENQ                       5
#define	C_ACK                       6
#define	C_BEL                       7
#define	C_BS                        8
#define	C_HT                        9
#define	C_LF                       10
#define	C_VT                       11
#define	C_FF                       12
#define	C_CR                       13
#define	C_SO                       14
#define	C_SI                       15
#define	C_DLE                      16
#define	C_DC1                      17
#define	C_DC2                      18
#define	C_DC3                      19
#define	C_DC4                      20
#define	C_NAK                      21
#define	C_SYN                      22
#define	C_ETB                      23
#define	C_CAN                      24
#define	C_EM                       25
#define	C_SUB                      26
#define	C_ESC                      27
#define	C_IS4                      28
#define	C_IS3                      29
#define	C_IS2                      30
#define	C_IS1                      31
#define	C_space                    32
#define	C_exclamation_mark         33
#define	C_quotation_mark           34
#define	C_pound_sign               35
#define	C_dollar_sign              36
#define	C_percent                  37
#define	C_ampersand                38
#define	C_apostrophe               39
#define	C_left_parenthesis         40
#define	C_right_parenthesis        41
#define	C_asterisk                 42
#define	C_plus_sign                43
#define	C_comma                    44
#define	C_hyphen                   45
#define	C_period                   46
#define	C_slash                    47
#define	C_zero                     48
#define	C_one                      49
#define	C_two                      50
#define	C_three                    51
#define	C_four                     52
#define	C_five                     53
#define	C_six                      54
#define	C_seven                    55
#define	C_eight                    56
#define	C_nine                     57
#define	C_colon                    58
#define	C_semicolon                59
#define	C_less_than                60
#define	C_equals_sign              61
#define	C_greater_than             62
#define	C_question_mark            63
#define	C_commercial_at            64
#define	C_A                        65
#define	C_B                        66
#define	C_C                        67
#define	C_D                        68
#define	C_E                        69
#define	C_F                        70
#define	C_G                        71
#define	C_H                        72
#define	C_I                        73
#define	C_J                        74
#define	C_K                        75
#define	C_L                        76
#define	C_M                        77
#define	C_N                        78
#define	C_O                        79
#define	C_P                        80
#define	C_Q                        81
#define	C_R                        82
#define	C_S                        83
#define	C_T                        84
#define	C_U                        85
#define	C_V                        86
#define	C_W                        87
#define	C_X                        88
#define	C_Y                        89
#define	C_Z                        90
#define	C_left_square_bracket      91
#define	C_back_slash               92
#define	C_right_square_bracket     93
#define	C_caret                    94
#define	C_underscore               95
#define	C_backquote                96
#define	C_a                        97
#define	C_b                        98
#define	C_c                        99
#define	C_d                       100
#define	C_e                       101
#define	C_f                       102
#define	C_g                       103
#define	C_h                       104
#define	C_i                       105
#define	C_j                       106
#define	C_k                       107
#define	C_l                       108
#define	C_m                       109
#define	C_n                       110
#define	C_o                       111
#define	C_p                       112
#define	C_q                       113
#define	C_r                       114
#define	C_s                       115
#define	C_t                       116
#define	C_u                       117
#define	C_v                       118
#define	C_w                       119
#define	C_x                       120
#define	C_y                       121
#define	C_z                       122
#define	C_left_brace              123
#define	C_vertical_bar            124
#define	C_right_brace             125
#define	C_tilde                   126
#define	C_delete                  127

#endif /* _CHARSETASCII_H_ */
